import { world, system, ScoreboardObjective } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";

const skills = ["attack", "defence", "mining", "gathering"];

function initializeScoreboards() {
    for (const skill of skills) {
        if (!world.scoreboard.getObjective(skill)) {
            world.scoreboard.addObjective(skill, skill);
        }
    }
}

function openSkillMenu(player) {
    const form = new ActionFormData().title("Skill Menu").body("Level Requirement: Wooden/Chain-2: Gold/Stone-5: Iron-8: Diamond-13: Netherite-17:");
    skills.forEach(skill => form.button(skill.charAt(0).toUpperCase() + skill.slice(1)));
    form.show(player).then(response => {
        if (!response.canceled) openSkillDetails(player, skills[response.selection]);
    });
}

function openSkillDetails(player, skill) {
    const currentLevel = getPlayerScore(player, skill);
    const requiredXP = currentLevel + 1;
    const playerXP = player.level;

    const form = new ActionFormData()
        .title(`§6${skill.charAt(0).toUpperCase() + skill.slice(1)} Skill`)
        .body(`§7Current Level: §b${currentLevel}\n§7XP Required: §c${requiredXP}\n§7Your XP: §a${playerXP}`)
        .button("Skill UP");

    form.show(player).then(response => {
        if (!response.canceled && response.selection === 0) attemptSkillUpgrade(player, skill);
    });
}

function attemptSkillUpgrade(player, skill) {
    const currentLevel = getPlayerScore(player, skill);
    const requiredXP = currentLevel + 1;
    const playerXP = player.level;

    if (playerXP >= requiredXP) {
        player.runCommandAsync(`/xp -${requiredXP}L @s`);
        updatePlayerScore(player, skill);
        player.sendMessage(`§aSkill upgraded!`);
        openSkillDetails(player, skill);
    } else {
        player.sendMessage(`§cNot enough XP! You need at least ${requiredXP} levels.`);
        openSkillDetails(player, skill);
    }
}

function getPlayerScore(player, skill) {
    const objective = world.scoreboard.getObjective(skill);
    return objective?.getScore(player.scoreboardIdentity) ?? 0;
}

function updatePlayerScore(player, skill) {
    const objective = world.scoreboard.getObjective(skill);
    if (objective) {
        const identity = player.scoreboardIdentity;
        if (identity) {
            let score = getPlayerScore(player, skill);
            objective.setScore(identity, score + 1);
            player.sendMessage(`§bYour ${skill} skill increased! (New Level: ${score + 1})`);
        }
    }
}

world.afterEvents.itemUse.subscribe(event => {
    const { itemStack, source } = event;
    if (source && itemStack?.typeId === "zc:lbook") {
        openSkillMenu(source);
    }
});

system.run(initializeScoreboards);